package cn.iocoder.yudao.module.appBase.service;

import cn.iocoder.yudao.module.appBase.domain.SysAnnouncement;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * 系统通知Service接口
 *
 * @author zcy
 * @date 2023-09-21
 */
public interface ISysAnnouncementService extends IService<SysAnnouncement>
{
    /**
     * 查询系统通知
     *
     * @param id 系统通知主键
     * @return 系统通知
     */
    public SysAnnouncement selectSysAnnouncementById(Long id);

    /**
     * 查询系统通知列表
     *
     * @param sysAnnouncement 系统通知
     * @return 系统通知集合
     */
    IPage<SysAnnouncement> selectSysAnnouncementList(SysAnnouncement sysAnnouncement, Page<SysAnnouncement> page);

    /**
     * 新增系统通知
     *
     * @param sysAnnouncement 系统通知
     * @return 结果
     */
    public int insertSysAnnouncement(SysAnnouncement sysAnnouncement);
    public void insertSysAnnouncements(SysAnnouncement sysAnnouncement);
    public void insertSysAnnouncements2(SysAnnouncement sysAnnouncement);

    /**
     * 修改系统通知
     *
     * @param sysAnnouncement 系统通知
     * @return 结果
     */
    public int updateSysAnnouncement(SysAnnouncement sysAnnouncement);

    /**
     * 批量删除系统通知
     *
     * @param ids 需要删除的系统通知主键集合
     * @return 结果
     */
    public int deleteSysAnnouncementByIds(Long[] ids);

    /**
     * 删除系统通知信息
     *
     * @param id 系统通知主键
     * @return 结果
     */
    public int deleteSysAnnouncementById(Long id);
}
